/*
 *   Copyright (c) 2012 Mike Heath.  All rights reserved.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package nats.client.spring.config;

import nats.client.spring.AnnotationConfigBeanPostProcessor;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.BeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * @author Mike Heath <elcapo@gmail.com>
 */
class AnnotationConfigDefinitionParser implements BeanDefinitionParser {
	private static final String ATTRIBUTE_NATS_REF = "nats-ref";

	@Override
	public BeanDefinition parse(Element element, ParserContext parserContext) {
		final BeanDefinitionBuilder builder = BeanDefinitionBuilder.genericBeanDefinition(AnnotationConfigBeanPostProcessor.class);

		builder.addConstructorArgReference(element.getAttribute(ATTRIBUTE_NATS_REF));

		final BeanDefinition beanDefinition = builder.getBeanDefinition();
		parserContext.getReaderContext().registerWithGeneratedName(beanDefinition);
		return beanDefinition;
	}
}
